@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
 import sys
+import re
 
 from halo import Halo
 
@@ -26,6 +27,9 @@ class Aggregator:
                 default_text="staging.prima.it",
             )
 
+            if address.startswith("http"):
+                address = re.sub(r"https?://?", "", address)
+
             change_request = self._captainhook.change_aggregator(aggregator, address)
             self._handle_captainhook_response(change_request, aggregator, address)
 
